"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListDirectoryBuckets = void 0;
const ListDirectoryBucketsCommand_1 = require("../commands/ListDirectoryBucketsCommand");
const S3Client_1 = require("../S3Client");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListDirectoryBucketsCommand_1.ListDirectoryBucketsCommand(input), ...args);
};
async function* paginateListDirectoryBuckets(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.ContinuationToken = token;
        input["MaxDirectoryBuckets"] = config.pageSize;
        if (config.client instanceof S3Client_1.S3Client) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected S3 | S3Client");
        }
        yield page;
        const prevToken = token;
        token = page.ContinuationToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListDirectoryBuckets = paginateListDirectoryBuckets;
